==> org-lsst-ccs-groovy-description-2.1.1-sources.jar: org/lsst/gruth/nodes/MethodCallsBuilder.java <==
package org.lsst.gruth.nodes;

import groovy.lang.Closure;
import groovy.lang.GroovyObjectSupport;
import org.codehaus.groovy.runtime.InvokerHelper;
import org.lsst.gruth.jutils.ComponentNode;
import org.lsst.gruth.jutils.MapArgs;

import java.util.List;

/**
 * @author bamade
 */
public class MethodCallsBuilder extends GroovyObjectSupport {
    private ComponentNode parent = new ComponentNode(null, "__calls__");

    public MethodCallsBuilder(ComponentNode support, Closure callsDescription) {
        //System.out.println("-------------" + callsDescription);
        callsDescription.setDelegate(this);
        Object trace = callsDescription.call(this);
        //System.out.println(" trace : " + trace);
    }

    public ComponentNode getCalls() {
        return parent;
    }

    public Object invokeMethod(String methodName) {
        return invokeMethod(methodName, null);
    }

    public Object invokeMethod(String methodName, Object args) {
        Object name = methodName;
        return doInvokeMethod(methodName, name, args);
    }


    protected Object doInvokeMethod(String methodName, Object name, Object args) {
        MapArgs argsMap = null;
        if (args == null) {
            //System.out.println("Called invokeMethod with name: " + name + " arguments: " + args);

        } else if (args instanceof MapArgs) {
            argsMap = (MapArgs) args;
        } else {
            List list = InvokerHelper.asList(args);
            Object[] array = list.toArray(new Object[list.size()]);
            argsMap = MapArgs.rawList(array);
            //System.out.println("Map args: " +argsMap);
        }
        ComponentNode child = new ComponentNode(parent, name, argsMap);
        parent.addChild(child);

        //System.out.println("Called invokeMethod with name: " + name + " arguments: " + argsMap);
        return null;

    }

}

==> org-lsst-ccs-groovy-description-2.1.3-sources.jar: org/lsst/gruth/nodes/MethodCallsBuilder.java <==
package org.lsst.gruth.nodes;

import groovy.lang.Closure;
import groovy.lang.GroovyObjectSupport;
import org.codehaus.groovy.runtime.InvokerHelper;
import org.lsst.gruth.jutils.MapArgs;

import java.util.List;
import org.lsst.ccs.description.DescriptiveNode;

/**
 * @author bamade
 * @deprecated seems not used anymore.
 */
@Deprecated
public class MethodCallsBuilder extends GroovyObjectSupport {
    private DescriptiveNode parent = new DescriptiveNode(null, "__calls__");

    public MethodCallsBuilder(DescriptiveNode support, Closure callsDescription) {
        //System.out.println("-------------" + callsDescription);
        callsDescription.setDelegate(this);
        Object trace = callsDescription.call(this);
        //System.out.println(" trace : " + trace);
    }

    public Object invokeMethod(String methodName) {
        return invokeMethod(methodName, null);
    }

    public Object invokeMethod(String methodName, Object args) {
        String name = methodName;
        return doInvokeMethod(methodName, name, args);
    }


    protected Object doInvokeMethod(String methodName, String name, Object args) {
        MapArgs argsMap = null;
        if (args == null) {
            //System.out.println("Called invokeMethod with name: " + name + " arguments: " + args);

        } else if (args instanceof MapArgs) {
            argsMap = (MapArgs) args;
        } else {
            List list = InvokerHelper.asList(args);
            Object[] array = list.toArray(new Object[list.size()]);
            argsMap = MapArgs.rawList(array);
            //System.out.println("Map args: " +argsMap);
        }
        DescriptiveNode child = new DescriptiveNode(parent, name, argsMap);
        parent.addChild(child);

        //System.out.println("Called invokeMethod with name: " + name + " arguments: " + argsMap);
        return null;

    }

}
